@@ -16,7 +16,7 @@ from torch import no_grad
 from torch.utils.data import Dataset
 
 from ._base import BaseEnvironnement
-from . import check_tensor_dict, check_tensor
+from ._utils import check_tensor_dict, check_tensor
 
 class BaseRegressor(BaseEnvironnement, RegressorMixin):
     r"""
@@ -164,7 +164,7 @@ class BaseRegressorOnline(BaseRegressor):
             y=y,
             eval_dataset=None,
             nb_epoch=1,
-            kargs_dataloader=dict(
+            dataloader_kargs=dict(
                 batch_size=1,
                 shuffle=False,
                 drop_last=False
@@ -179,7 +179,6 @@ class BaseRegressorOnline(BaseRegressor):
         X: Iterable,
         y: Optional[Iterable]=None,
         predict: bool=False,
-        needs_proba: bool=False,
         gap: int=0,
         treat_nan_inf: bool=True,
         fill_nan: float=0,
